@@ -44,6 +44,15 @@ def format_date_time(timestamp):
     )
 
 
+def addr_to_host_port(addr):
+    host = 'unix'
+    port = ''
+    if isinstance(addr, tuple):
+        host = addr[0]
+        port = addr[1]
+    return (host, port)
+
+
 # Collections of error codes to compare against.  Not all attributes are set
 # on errno module on all platforms, so some are literals :(
 BAD_SOCK = set((errno.EBADF, 10053))
@@ -288,11 +297,6 @@ class HttpProtocol(BaseHTTPServer.BaseHTTPRequestHandler):
     minimum_chunk_size = MINIMUM_CHUNK_SIZE
     capitalize_response_headers = True
 
-    # Disable nagle algorithm for this socket, if True.
-    # Use only when wbufsize != 0, to avoid small packets.
-    # Contrary to stdlib, it's enabled by default.
-    disable_nagle_algorithm = True
-
     # https://github.com/eventlet/eventlet/issues/295
     # Stdlib default is 0 (unbuffered), but then `wfile.writelines()` looses data
     # so before going back to unbuffered, remove any usage of `writelines`.
@@ -302,8 +306,13 @@ class HttpProtocol(BaseHTTPServer.BaseHTTPRequestHandler):
         # overriding SocketServer.setup to correctly handle SSL.Connection objects
         conn = self.connection = self.request
 
-        if self.disable_nagle_algorithm:
-            conn.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, True)
+        # TCP_QUICKACK is a better alternative to disabling Nagle's algorithm
+        # https://news.ycombinator.com/item?id=10607422
+        if getattr(socket, 'TCP_QUICKACK', None):
+            try:
+                conn.setsockopt(socket.IPPROTO_TCP, socket.TCP_QUICKACK, True)
+            except socket.error:
+                pass
 
         try:
             self.rfile = conn.makefile('rb', self.rbufsize)
@@ -366,7 +375,7 @@ class HttpProtocol(BaseHTTPServer.BaseHTTPRequestHandler):
             self.rfile = orig_rfile
 
         content_length = self.headers.get('content-length')
-        if content_length:
+        if content_length is not None:
             try:
                 int(content_length)
             except ValueError:
@@ -536,8 +545,8 @@ class HttpProtocol(BaseHTTPServer.BaseHTTPRequestHandler):
                         self.close_connection = 1
                         self.server.log.error((
                             'chunked encoding error while discarding request body.'
-                            + ' ip={0} request="{1}" error="{2}"').format(
-                                self.get_client_ip(), self.requestline, e,
+                            + ' client={0} request="{1}" error="{2}"').format(
+                                self.get_client_address()[0], self.requestline, e,
                         ))
             finish = time.time()
 
@@ -545,9 +554,11 @@ class HttpProtocol(BaseHTTPServer.BaseHTTPRequestHandler):
                 hook(self.environ, *args, **kwargs)
 
             if self.server.log_output:
+                client_host, client_port = self.get_client_address()
+
                 self.server.log.info(self.server.log_format % {
-                    'client_ip': self.get_client_ip(),
-                    'client_port': self.client_address[1],
+                    'client_ip': client_host,
+                    'client_port': client_port,
                     'date_time': self.log_date_time_string(),
                     'request_line': self.requestline,
                     'status_code': status_code[0],
@@ -555,13 +566,14 @@ class HttpProtocol(BaseHTTPServer.BaseHTTPRequestHandler):
                     'wall_seconds': finish - start,
                 })
 
-    def get_client_ip(self):
-        client_ip = self.client_address[0]
+    def get_client_address(self):
+        host, port = addr_to_host_port(self.client_address)
+
         if self.server.log_x_forwarded_for:
             forward = self.headers.get('X-Forwarded-For', '').replace(' ', '')
             if forward:
-                client_ip = "%s,%s" % (forward, client_ip)
-        return client_ip
+                host = forward + ',' + host
+        return (host, port)
 
     def get_environ(self):
         env = self.server.get_environ()
@@ -587,11 +599,13 @@ class HttpProtocol(BaseHTTPServer.BaseHTTPRequestHandler):
             env['CONTENT_LENGTH'] = length
         env['SERVER_PROTOCOL'] = 'HTTP/1.0'
 
-        host, port = self.request.getsockname()[:2]
-        env['SERVER_NAME'] = host
-        env['SERVER_PORT'] = str(port)
-        env['REMOTE_ADDR'] = self.client_address[0]
-        env['REMOTE_PORT'] = str(self.client_address[1])
+        sockname = self.request.getsockname()
+        server_addr = addr_to_host_port(sockname)
+        env['SERVER_NAME'] = server_addr[0]
+        env['SERVER_PORT'] = str(server_addr[1])
+        client_addr = addr_to_host_port(self.client_address)
+        env['REMOTE_ADDR'] = client_addr[0]
+        env['REMOTE_PORT'] = str(client_addr[1])
         env['GATEWAY_INTERFACE'] = 'CGI/1.1'
 
         try:
@@ -601,10 +615,11 @@ class HttpProtocol(BaseHTTPServer.BaseHTTPRequestHandler):
         else:
             headers = [h.split(':', 1) for h in headers]
 
-        for k, v in headers:
+        env['headers_raw'] = headers_raw = tuple((k, v.strip()) for k, v in headers)
+        for k, v in headers_raw:
             k = k.replace('-', '_').upper()
-            v = v.strip()
-            if k in env:
+            if k in ('CONTENT_TYPE', 'CONTENT_LENGTH'):
+                # These do not get the HTTP_ prefix and were handled above
                 continue
             envk = 'HTTP_' + k
             if envk in env:
@@ -799,7 +814,8 @@ def server(sock, site,
 
     :param sock: Server socket, must be already bound to a port and listening.
     :param site: WSGI application function.
-    :param log: File-like object that logs should be written to.
+    :param log: logging.Logger instance or file-like object that logs should be written to.
+                If a Logger instance is supplied, messages are sent to the INFO log level.
                 If not specified, sys.stderr is used.
     :param environ: Additional parameters that go into the environ dictionary of every request.
     :param max_size: Maximum number of client connections opened at any time by this server.
